#ifndef __IFP_H__
#define __IFP_H__

#include <usb.h>

#define IFP_FILE_BUFLEN		0x4000
#define IFP_BULK_MAXPATHLEN	0x400
#define IFP_MAXPATHLEN		0x200
#define IFP_LSBUFLEN		0x100

typedef struct file_infos
{
	char name[IFP_MAXPATHLEN];
	char *mimetype;
	struct file_infos *next;
	int size;
	int is_file;
} ifp_file_info;

typedef void (*ifp_progress)(const char *);

#define iRiver_Vendor         0x4102

#define OGG_MIMETYPE          "application/ogg"
#define MP3_MIMETYPE          "audio/mpeg"
#define WMA_MIMETYPE          "audio/x-ms-wma"
#define ASF_MIMETYPE          "audio/x-ms-asf"
#define DEFAULT_MIMETYPE      "application/octet-stream"
#define DIRECTORY_MIMETYPE    "x-directory/normal"
#define FIRMWARE_BASENAMETC   "IFP-1XXTC.HEX"
#define FIRMWARE_BASENAMET    "IFP-1XXT.HEX"

/* Return codes */
#define IRIVER_OK                           0
#define IRIVER_LOCAL_FILE_OPEN_ERROR        -1
#define IRIVER_GENERIC_USB_ERROR            -2
#define IRIVER_NO_FREE_SPACE                -3
#define IRIVER_NO_USB_BUS                   -4
#define IRIVER_NO_DEVICE                    -5
#define IRIVER_NO_IFP                       -6
#define IRIVER_FIRMWARE_BASENAME_INCORRECT  -7
#define IRIVER_UPLOAD_ERROR                 -8
#define IRIVER_CANNOT_SEND_FILENAME         -9
#define IRIVER_FILE_NOT_FOUND               -10
#define IRIVER_FILE_EXISTS                  -11
#define IRIVER_DIRECTORY_NOT_FOUND          -12
#define IRIVER_DIRECTORY_EXISTS             -13
#define IRIVER_DIRECTORY_NOT_EMPTY          -14
#define IRIVER_BUSY						    -15
#define IRIVER_PERMISSION_DENIED			-16
/* Initialization types */
#define IRIVER_INIT                         0
#define IRIVER_REINIT                       -1

extern int   ifp_get_capacity(usb_dev_handle *dh);
extern int   ifp_get_free(usb_dev_handle *dh);
extern int   ifp_upload_file(usb_dev_handle *dh, const char *name, const char *fn, ifp_progress progress);
extern int   ifp_delete_file(usb_dev_handle *dh, const char *name, ifp_progress progress);
extern int   ifp_empty_dir(usb_dev_handle *dh, const char *name);
extern int   ifp_delete_dir(usb_dev_handle *dh, const char *name, ifp_progress progress);
extern int   ifp_make_dir(usb_dev_handle *dh, const char *name);
extern int   ifp_download_file(usb_dev_handle *dh, const char *name, const char *fn, ifp_progress progress);
extern int   ifp_battery_condition(usb_dev_handle *dh);
extern float ifp_firmware_version(usb_dev_handle *dh);
extern int   ifp_init(usb_dev_handle **dh, int init_type);
extern void  ifp_release(usb_dev_handle *dh);
extern int   ifp_ls(usb_dev_handle *dh, const char *name, ifp_file_info **p);
extern int   ifp_firmware_update(usb_dev_handle **dh, char *name);
extern int   ifp_format(usb_dev_handle *dh);
extern const char *ifp_error_to_string(int error);
extern int   ifp_get_info(usb_dev_handle *dh, const char *name, ifp_file_info **p);
extern int   ifp_model_name(usb_dev_handle *dh, char *string);
extern void  ifp_free_file_list(ifp_file_info **first);
extern int   ifp_file_exists(usb_dev_handle *dh, const char *name);
extern int   ifp_download_dir(usb_dev_handle *dh, const char *dname, const char *dn, ifp_progress progress);
extern int   ifp_upload_dir(usb_dev_handle *dh, const char *dname, const char *dn, ifp_progress progress);

#endif
